@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: io.h 2466 2015-02-23 06:06:56Z saaadhu $ */
+/* $Id: io.h 2499 2016-01-28 14:41:31Z pitchumani $ */
 
 /** \file */
 /** \defgroup avr_io <avr/io.h>: AVR device-specific IO definitions
@@ -202,8 +202,10 @@
 #  include <avr/iom64a.h>
 #elif defined (__AVR_ATmega640__)
 #  include <avr/iom640.h>
-#elif defined (__AVR_ATmega644__) || defined (__AVR_ATmega644A__)
+#elif defined (__AVR_ATmega644__)
 #  include <avr/iom644.h>
+#elif defined (__AVR_ATmega644A__)
+#  include <avr/iom644a.h>
 #elif defined (__AVR_ATmega644P__)
 #  include <avr/iom644p.h>
 #elif defined (__AVR_ATmega644PA__)
@@ -220,6 +222,8 @@
 #  include <avr/iom649p.h>
 #elif defined (__AVR_ATmega64HVE__)
 #  include <avr/iom64hve.h>
+#elif defined (__AVR_ATmega64HVE2__)
+#  include <avr/iom64hve2.h>
 #elif defined (__AVR_ATmega103__)
 #  include <avr/iom103.h>
 #elif defined (__AVR_ATmega32__)
@@ -318,6 +322,8 @@
 #  include <avr/iom48a.h>
 #elif defined (__AVR_ATmega48PA__)
 #  include <avr/iom48pa.h>
+#elif defined (__AVR_ATmega48PB__)
+#  include <avr/iom48pb.h>
 #elif defined (__AVR_ATmega48P__)
 #  include <avr/iom48p.h>
 #elif defined (__AVR_ATmega88__)
@@ -328,6 +334,8 @@
 #  include <avr/iom88p.h>
 #elif defined (__AVR_ATmega88PA__)
 #  include <avr/iom88pa.h>
+#elif defined (__AVR_ATmega88PB__)
+#  include <avr/iom88pb.h>
 #elif defined (__AVR_ATmega8515__)
 #  include <avr/iom8515.h>
 #elif defined (__AVR_ATmega8535__)
@@ -392,10 +400,14 @@
 #  include <avr/iotn44.h>
 #elif defined (__AVR_ATtiny44A__)
 #  include <avr/iotn44a.h>
+#elif defined (__AVR_ATtiny441__)
+#  include <avr/iotn441.h>
 #elif defined (__AVR_ATtiny84__)
 #  include <avr/iotn84.h>
 #elif defined (__AVR_ATtiny84A__)
-#  include <avr/iotn84a.h>  
+#  include <avr/iotn84a.h> 
+#elif defined (__AVR_ATtiny841__)
+#  include <avr/iotn841.h> 
 #elif defined (__AVR_ATtiny261__)
 #  include <avr/iotn261.h>
 #elif defined (__AVR_ATtiny261A__)
@@ -424,6 +436,8 @@
 #  include <avr/iotn1634.h>
 #elif defined (__AVR_AT90SCR100__)
 #  include <avr/io90scr100.h>
+#elif defined (__AVR_ATxmega8E5__)
+#  include <avr/iox8e5.h>
 #elif defined (__AVR_ATxmega16A4__)
 #  include <avr/iox16a4.h>
 #elif defined (__AVR_ATxmega16A4U__)
@@ -436,10 +450,16 @@
 #  include <avr/iox32a4.h>
 #elif defined (__AVR_ATxmega32A4U__)
 #  include <avr/iox32a4u.h>
+#elif defined (__AVR_ATxmega32C3__)
+#  include <avr/iox32c3.h>
 #elif defined (__AVR_ATxmega32C4__)
 #  include <avr/iox32c4.h>
+#elif defined (__AVR_ATxmega32D3__)
+#  include <avr/iox32d3.h>
 #elif defined (__AVR_ATxmega32D4__)
 #  include <avr/iox32d4.h>
+#elif defined (__AVR_ATxmega32E5__)
+#  include <avr/iox32e5.h>
 #elif defined (__AVR_ATxmega64A1__)
 #  include <avr/iox64a1.h>
 #elif defined (__AVR_ATxmega64A1U__)
@@ -504,8 +524,16 @@
 #  include <avr/iox384c3.h>
 #elif defined (__AVR_ATxmega384D3__)
 #  include <avr/iox384d3.h>
+#elif defined (__AVR_ATA5702M322__)
+#  include <avr/ioa5702m322.h>
+#elif defined (__AVR_ATA5782__)
+#  include <avr/ioa5782.h>
 #elif defined (__AVR_ATA5790__)
 #  include <avr/ioa5790.h>
+#elif defined (__AVR_ATA5790N__)
+#  include <avr/ioa5790n.h>
+#elif defined (__AVR_ATA5831__)
+#  include <avr/ioa5831.h>
 #elif defined (__AVR_ATA5272__)
 #  include <avr/ioa5272.h>
 #elif defined (__AVR_ATA5505__)
@@ -518,6 +546,18 @@
 #  include <avr/ioa6286.h>
 #elif defined (__AVR_ATA6289__)
 #  include <avr/ioa6289.h>
+#elif defined (__AVR_ATA6612C__)
+#  include <avr/ioa6612c.h>
+#elif defined (__AVR_ATA6613C__)
+#  include <avr/ioa6613c.h>
+#elif defined (__AVR_ATA6614Q__)
+#  include <avr/ioa6614q.h>
+#elif defined (__AVR_ATA6616C__)
+#  include <avr/ioa6616c.h>
+#elif defined (__AVR_ATA6617C__)
+#  include <avr/ioa6617c.h>
+#elif defined (__AVR_ATA664251__)
+#  include <avr/ioa664251.h>
 /* avr1: the following only supported for assembler programs */
 #elif defined (__AVR_ATtiny28__)
 #  include <avr/iotn28.h>
