@@ -29,7 +29,7 @@
   ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
   POSSIBILITY OF SUCH DAMAGE. */
 
-/* $Id: wdt.h 2476 2015-06-18 09:40:35Z pitchumani $ */
+/* $Id: wdt.h 2503 2016-02-07 22:59:47Z joerg_wunsch $ */
 
 /*
    avr/wdt.h - macros for AVR watchdog timer
@@ -98,6 +98,7 @@
 
 #define wdt_reset() __asm__ __volatile__ ("wdr")
 
+#ifndef __DOXYGEN__
 
 #if defined(WDP3)
 # define _WD_PS3_MASK       _BV(WDP3)
@@ -119,6 +120,8 @@
 #define _WD_CHANGE_BIT      WDCE
 #endif
 
+#endif	/* !__DOXYGEN__ */
+
 
 /**
    \ingroup avr_watchdog
@@ -508,37 +511,37 @@ void wdt_disable (void)
 #define WDTO_15MS   0
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS */
+    See \c WDTO_15MS */
 #define WDTO_30MS   1
 
-/** \ingroup avr_watchdog See
-    \c WDT0_15MS */
+/** \ingroup avr_watchdog
+    See \c WDTO_15MS */
 #define WDTO_60MS   2
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS */
+    See \c WDTO_15MS */
 #define WDTO_120MS  3
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS */
+    See \c WDTO_15MS */
 #define WDTO_250MS  4
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS */
+    See \c WDTO_15MS */
 #define WDTO_500MS  5
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS */
+    See \c WDTO_15MS */
 #define WDTO_1S     6
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS */
+    See \c WDTO_15MS */
 #define WDTO_2S     7
 
 #if defined(__DOXYGEN__) || defined(WDP3)
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS
+    See \c WDTO_15MS
     Note: This is only available on the 
     ATtiny2313, 
     ATtiny24, ATtiny44, ATtiny84, ATtiny84A,
@@ -559,7 +562,7 @@ void wdt_disable (void)
 #define WDTO_4S     8
 
 /** \ingroup avr_watchdog
-    See \c WDT0_15MS
+    See \c WDTO_15MS
     Note: This is only available on the 
     ATtiny2313, 
     ATtiny24, ATtiny44, ATtiny84, ATtiny84A,
